@@ -1,14 +1,11 @@
 from time import time
-from sys import platform
+from sys import platform, exit
 
 if platform == 'linux' or platform == 'linux2':
     filepath = '/tmp/py_simple_healthcheck'
 else:
     filepath = 'py_simple_healthcheck'
 
-class UnhealthyException(Exception):
-    pass
-
 def health_check(timeout):
     with open(filepath, 'w+') as file:
         file.write(f'{str(int(time()))},{str(timeout)}')
@@ -19,7 +16,7 @@ def is_healthy():
             content = file.read()
             timestamp, timeout = content.split(',')
             if time() > int(timestamp) + int(timeout):
-                raise UnhealthyException()
+                print('Unhealthy')
     
     except FileNotFoundError as e:
         print('Healthcheck file not found', flush=True)
